Error

Enum Error 

pub enum Error {
    Arg(OsString),
    Git(Error),
    BranchName,
    Trunk(Error),
    Unclean,
}

Variants



Arg(OsString)

An unrecognized command line argument was supplied.



Git(Error)

Git produced unexpected output. (If Git itself is not found, we panic.)



BranchName

A branch name was expected as an argument, but was not provided. https://en.wikipedia.org/wiki/Argument_Clinic



Trunk(Error)

No local trunk branch could be identified. This can happen if a command is run outside of any git repo, or if the repo has no local branch matching any recognized trunk name.



Unclean

The Git working copy has uncommitted changes.